@@ -3,9 +3,10 @@ References:
     https://github.com/lohriialo/photoshop-scripting-python/blob/master/ApplyFilters.py
 
 """
+import os
+
 # selections in the open document.
 import photoshop as ps
-import os
 
 # Start up Photoshop application
 app = ps.Application()
@@ -25,9 +26,7 @@ nArtLayers = len(
     list((i, x) for i, x in enumerate(docRef.layerSets[nLayerSets].artLayers)),
 )
 
-active_layer = docRef.activeLayer = docRef.layerSets[nLayerSets].artLayers[
-    nArtLayers
-]
+active_layer = docRef.activeLayer = docRef.layerSets[nLayerSets].artLayers[nArtLayers]
 sel_area = ((0, 212), (300, 212), (300, 300), (0, 300))
 docRef.selection.select(sel_area, ps.SelectionType.ReplaceSelection, 20, True)
 print(active_layer.name)
@@ -40,12 +39,10 @@ backColor.hsb.brightness = 100
 app.backgroundColor = backColor
 
 sel_area2 = ((120, 20), (210, 20), (210, 110), (120, 110))
-docRef.selection.select(sel_area2, ps.SelectionType.ReplaceSelection, 25,
-                        False)
+docRef.selection.select(sel_area2, ps.SelectionType.ReplaceSelection, 25, False)
 active_layer.applyDiffuseGlow(9, 12, 15)
 active_layer.applyGlassEffect(
-    7, 3, 7, False, ps.TextureType.TinyLensTexture,
-    None,
+    7, 3, 7, False, ps.TextureType.TinyLensTexture, None,
 )
 docRef.selection.deselect()
 
