@@ -1,4 +1,3 @@
-
 import photoshop as ps
 
 app = ps.Application()
@@ -9,8 +8,7 @@ if len(app.documents) < 1:
     if start_ruler_units is not ps.Units.Pixels:
         app.preferences.rulerUnits = ps.Units.Pixels
     docRef = app.documents.add(
-        320, 240, 72, None, ps.NewDocumentMode.NewRGB,
-        ps.DocumentFill.BackgroundColor,
+        320, 240, 72, None, ps.NewDocumentMode.NewRGB, ps.DocumentFill.BackgroundColor,
     )
 else:
     docRef = app.activeDocument
