@@ -1,20 +1,38 @@
-# Import local modules
-from photoshop._core import Photoshop
+"""The active containment object for layers and all other objects.
+
+The basic canvas for the file.
+
+- Access the object for the currently active document through
+  `Application.activeDocument.`
+- You can access other documents or iterate through all open documents using
+  in the `Application.documents` collection. You can access individual
+  documents in the list by index, or use Documents.getByName() to retrieve
+  them by name.
+- Create documents programmatically using the Documents.add() method.
+
+
+"""
+
+# Import built-in modules
+from pathlib import Path
+
 from photoshop._artlayer import ArtLayer
 from photoshop._artlayers import ArtLayers
-from photoshop.errors import COMError
+
+# Import local modules
+from photoshop._core import Photoshop
+from photoshop._documentinfo import DocumentInfo
 from photoshop._layers import Layers
+from photoshop._layerSet import LayerSet
 from photoshop._layerSets import LayerSets
 from photoshop._selection import Selection
-from photoshop._layerSet import LayerSet
-from photoshop.enumerations import ExtensionType
-from photoshop.enumerations import SaveOptions
-from photoshop._documentinfo import DocumentInfo
+from photoshop.enumerations import ExtensionType, SaveOptions
+from photoshop.errors import COMError
 
 
 # pylint: disable=too-many-public-methods
 class Document(Photoshop):
-    object_name = 'Application'
+    object_name = "Application"
 
     def __init__(self, parent):
         super().__init__(parent=parent)
@@ -25,15 +43,22 @@ class Document(Photoshop):
 
     @property
     def activeLayer(self):
+        """The selected layer."""
         type_ = self.eval_javascript("app.activeDocument.activeLayer.typename")
-        mappings = {"LayerSet": LayerSet,
-                    "ArtLayer": ArtLayer}
+        mappings = {"LayerSet": LayerSet, "ArtLayer": ArtLayer}
         func = mappings[type_]
         return func(self.app.activeLayer)
 
     @activeLayer.setter
-    def activeLayer(self, item):
-        self.app.activeLayer = item
+    def activeLayer(self, layer):
+        """Sets the select layer as active layer.
+
+        Args:
+            layer (photoshop._artlayer.ArtLayer or
+                   photoshop._layerSet.LayerSet): The artLayer.
+
+        """
+        self.app.activeLayer = layer
 
     @property
     def activeChannels(self):
@@ -74,12 +99,20 @@ class Document(Photoshop):
         for color profile kind (to indicate a custom color profile)."""
         return self.app.colorProfileName
 
+    @colorProfileName.setter
+    def colorProfileName(self, name):
+        self.app.colorProfileName = name
+
     @property
     def colorProfileType(self):
         """The type of color model that defines the working space of the
         Document."""
         return self.app.colorProfileType
 
+    @colorProfileType.setter
+    def colorProfileType(self, profile_type):
+        self.app.colorProfileType = profile_type
+
     @property
     def colorSamplers(self):
         """The current color samplers associated with the Document."""
@@ -99,11 +132,10 @@ class Document(Photoshop):
     def fullName(self):
         """The full path name of the Document."""
         try:
-            return self.app.fullName
+            return Path(self.app.fullName)
         except COMError:
             self.eval_javascript(
-                'alert ("Please save your Document first!",'
-                '"{}")'.format(self.name),
+                'alert ("Please save your Document first!",' '"{}")'.format(self.name),
             )
 
     @property
@@ -163,7 +195,7 @@ class Document(Photoshop):
         return self.app.Mode
 
     @property
-    def name(self):
+    def name(self) -> str:
         """The Document name."""
         return self.app.name
 
@@ -176,11 +208,10 @@ class Document(Photoshop):
     def path(self):
         """The path to the Document."""
         try:
-            return self.app.Path
+            return Path(self.app.path)
         except COMError:
             self.eval_javascript(
-                'alert ("Please save your Document first!",'
-                '"{}")'.format(self.name),
+                'alert ("Please save your Document first!",' '"{}")'.format(self.name),
             )
 
     @path.setter
@@ -299,8 +330,9 @@ class Document(Photoshop):
         """Saves the Document."""
         return self.app.save()
 
-    def saveAs(self, file_path, options, asCopy=True,
-               extensionType=ExtensionType.Lowercase):
+    def saveAs(
+        self, file_path, options, asCopy=True, extensionType=ExtensionType.Lowercase
+    ):
         """Saves the documents with the specified save options.
 
         Args:
@@ -308,10 +340,7 @@ class Document(Photoshop):
             options (photoshop.JPEGSaveOptions): Save options.
             asCopy (bool):
         """
-        return self.app.saveAs(
-            file_path, options, asCopy,
-            extensionType,
-        )
+        return self.app.saveAs(file_path, options, asCopy, extensionType,)
 
     def splitChannels(self):
         """Splits the channels of the document."""
@@ -325,16 +354,21 @@ class Document(Photoshop):
         """
         self.eval_javascript(
             f"app.activeDocument.suspendHistory('{historyString}',"
-            f" '{javaScriptString}')")
+            f" '{javaScriptString}')"
+        )
 
     def trap(self, width):
-        """Applies trapping to a CMYK document. Valid only when ‘mode’ = CMYK."""
+        """
+        Applies trapping to a CMYK document.
+        Valid only when ‘mode’ = CMYK.
+
+        """
         self.app.trap(width)
 
     def trim(self, *args, **kwargs):
         return self.app.trim(*args, **kwargs)
 
-    def resizeImage(self, width, height, resolution=72, psAutomatic=8):
+    def resizeImage(self, width, height, resolution=72, automatic=8):
         """Changes the size of the image.
 
         Args:
@@ -342,10 +376,5 @@ class Document(Photoshop):
             height: The desired height of the image.
             resolution: The resolution (in pixels per inch)
 
-        Returns:
-
         """
-        return self.app.resizeImage(
-            width, height, resolution,
-            psAutomatic,
-        )
+        return self.app.resizeImage(width, height, resolution, automatic)
