@@ -31,5 +31,4 @@ class LayerSets(Photoshop):
         for layer in self.app:
             if name == layer.name:
                 return LayerSet(layer)
-        raise PhotoshopPythonAPIError(f'Could not find a LayerSet named '
-                                      f'"{name}"')
+        raise PhotoshopPythonAPIError(f"Could not find a LayerSet named " f'"{name}"')
