@@ -1,48 +1,49 @@
+"""Defines a CMYK color, used in the `SolidColor` object."""
+
 # Import local modules
+from __future__ import annotations
+
 from photoshop._core import Photoshop
 
 
 class CMYKColor(Photoshop):
+    object_name = "CMYKColor"
 
     def __init__(self, parent):
         super().__init__(parent=parent)
-        self.cyan = 75
-        self.magenta = 68
-        self.yellow = 67
-        self.black = 90
 
     @property
-    def black(self):
+    def black(self) -> int:
         """The black color value. Range: 0.0 to 100.0."""
-        return self.app.black
+        return round(self.app.black)
 
     @black.setter
-    def black(self, value):
+    def black(self, value: int):
         self.app.black = value
 
     @property
-    def cyan(self):
+    def cyan(self) -> int:
         """The cyan color value. Range: 0.0 to 100.0."""
-        return self.app.cyan
+        return round(self.app.cyan)
 
     @cyan.setter
     def cyan(self, value: int):
         self.app.cyan = value
 
     @property
-    def magenta(self):
+    def magenta(self) -> int:
         """The magenta color value. Range: 0.0 to 100.0."""
-        return self.app.magenta
+        return round(self.app.magenta)
 
     @magenta.setter
     def magenta(self, value: int):
         self.app.magenta = value
 
     @property
-    def yellow(self):
+    def yellow(self) -> int:
         """The yellow color value. Range: 0.0 to 100.0."""
-        return self.app.yellow
+        return round(self.app.yellow)
 
     @yellow.setter
-    def yellow(self, value: float):
+    def yellow(self, value: int):
         self.app.yellow = value
