@@ -2,16 +2,14 @@ from photoshop._core import Photoshop
 
 
 class LabColor(Photoshop):
+    object_name = "LabColor"
 
     def __init__(self, parent):
         super().__init__(parent=parent)
-        self.A = 0
-        self.b = 0
-        self.L = 0
 
     @property
     def A(self):
-        return self.app.A
+        return round(self.app.A)
 
     @A.setter
     def A(self, value):
@@ -19,16 +17,15 @@ class LabColor(Photoshop):
 
     @property
     def B(self):
-        return self.app.B
+        return round(self.app.B)
 
     @B.setter
     def B(self, value):
-        print(value)
         self.app.B = value
 
     @property
     def L(self):
-        return self.app.L
+        return round(self.app.L)
 
     @L.setter
     def L(self, value):
