@@ -1,19 +1,18 @@
+from photoshop.save_options.bmp import BMPSaveOptions
 from photoshop.save_options.gif import GIFSaveOptions
 from photoshop.save_options.jpg import JPEGSaveOptions
 from photoshop.save_options.pdf import PDFSaveOptions
-from photoshop.save_options.png import ExportOptionsSaveForWeb
-from photoshop.save_options.png import PNGSaveOptions
+from photoshop.save_options.png import ExportOptionsSaveForWeb, PNGSaveOptions
 from photoshop.save_options.psd import PhotoshopSaveOptions
 from photoshop.save_options.tif import TiffSaveOptions
-from photoshop.save_options.bmp import BMPSaveOptions
 
 __all__ = [
-    'BMPSaveOptions',
-    'GIFSaveOptions',
-    'JPEGSaveOptions',
-    'PDFSaveOptions',
-    'ExportOptionsSaveForWeb',
-    'PNGSaveOptions',
-    'PhotoshopSaveOptions',
-    'TiffSaveOptions',
+    "BMPSaveOptions",
+    "GIFSaveOptions",
+    "JPEGSaveOptions",
+    "PDFSaveOptions",
+    "ExportOptionsSaveForWeb",
+    "PNGSaveOptions",
+    "PhotoshopSaveOptions",
+    "TiffSaveOptions",
 ]
